Skip to contents

A sample data.frame containing Differential Expression Analysis, generated with DESeq2

Format

A data.frame object

Value

A sample data.frame object, extracted from DESeq2 results

Details

This data.frame object contains the results of a Differential Expression Analysis performed on data from the macrophage package, more precisely contrasting the counts from naive macrophage to those associated with IFNg.

The code to create said object can be found in the folder /inst/scripts in the EMMA package, the file is called create_datasets_examples.R.

References

Alasoo, et al. "Shared genetic effects on chromatin and gene expression indicate a role for enhancer priming in immune response", Nature Genetics, January 2018 doi: 10.1038/s41588-018-0046-7.