Append or replace the extra field in the EMMA_record attribute
of a result object returned by EMMA_run(). This allows users to manually
provide additional annotation or contextual information that could not be
captured automatically
Usage
EMMA_add_custom_metadata(res, extra = list())Arguments
- res
A functional enrichment analysis results object as returned by
EMMA_run()- extra
A named list of user-defined metadata elements to store in the
extrafield