A sample data.frame containing Differential Expression Analysis, generated with DESeq2
Source: R/EMMA-data.R
de_res_IFNg_vs_naive.RdA sample data.frame containing Differential Expression Analysis, generated
with DESeq2
Details
This data.frame object contains the results of a Differential
Expression Analysis performed on data from the macrophage package, more
precisely contrasting the counts from naive macrophage to those associated
with IFNg.
The code to create said object can be found in the folder /inst/scripts in
the EMMA package, the file is called create_datasets_examples.R.