A sample list containing Functional Enrichment Analysis results, generated with gprofiler2
Source: R/EMMA-data.R
fea_res.RdA sample list containing Functional Enrichment Analysis results,
generated with gprofiler2
Value
A sample list containing the FEA results result and metadata.
This results object has the EMMA_record attribute.
Details
This list object contains the result table and metadata of the
functional enrichment analysis (FEA) performed on the macrophage data,
specifically using the gost() function from the gprofiler2 package, and
wrapped in EMMA_run()
The code to create said object can be found in the folder /inst/scripts in
the EMMA package, the file is called create_datasets_examples.R.