A sample character vector containing the background gene list used to perform FEA on the macrophage dataset
Source: R/EMMA-data.R
gene_universe.RdA sample character vector containing the background gene list used to
perform FEA on the macrophage dataset